@@ -11,16 +11,26 @@
 # (c) 2015-2016 Valentin Samir
 """Default values for the app's settings"""
 from django.conf import settings
-from django.contrib.staticfiles.templatetags.staticfiles import static
+from django.templatetags.static import static
 from django.utils.translation import ugettext_lazy as _
 
 from importlib import import_module
 
 
-#: URL to the logo showed in the up left corner on the default templates.
-CAS_LOGO_URL = static("cas_server/logo.png")
-#: URL to the favicon (shortcut icon) used by the default templates. Default is a key icon.
-CAS_FAVICON_URL = static("cas_server/favicon.ico")
+try:
+    #: URL to the logo showed in the up left corner on the default templates.
+    CAS_LOGO_URL = static("cas_server/logo.png")
+    #: URL to the favicon (shortcut icon) used by the default templates. Default is a key icon.
+    CAS_FAVICON_URL = static("cas_server/favicon.ico")
+# is settings.DEBUG is False and collectstatics has not been run yet, the static function will
+# raise a ValueError because the file is not found.
+except ValueError:
+    #: URL to the logo showed in the up left corner on the default templates.
+    CAS_LOGO_URL = None
+    #: URL to the favicon (shortcut icon) used by the default templates. Default is a key icon.
+    CAS_FAVICON_URL = None
+
+
 #: Show the powered by footer if set to ``True``
 CAS_SHOW_POWERED = True
 #: URLs to css and javascript external components.
@@ -183,7 +193,7 @@ CAS_NEW_VERSION_HTML_WARNING = True
 CAS_NEW_VERSION_EMAIL_WARNING = True
 #: URL to the pypi json of the application. Used to retreive the version number of the last version.
 #: You should not change it.
-CAS_NEW_VERSION_JSON_URL = "https://pypi.python.org/pypi/django-cas-server/json"
+CAS_NEW_VERSION_JSON_URL = "https://pypi.org/pypi/django-cas-server/json"
 
 #: If the service message should be displayed on the login page
 CAS_SHOW_SERVICE_MESSAGES = True
