@@ -641,7 +641,11 @@ class Username(models.Model):
     #: ForeignKey to a :class:`ServicePattern`. :class:`Username` instances for a
     #: :class:`ServicePattern` are accessible thought its :attr:`ServicePattern.usernames`
     #: attribute.
-    service_pattern = models.ForeignKey(ServicePattern, related_name="usernames")
+    service_pattern = models.ForeignKey(
+        ServicePattern,
+        related_name="usernames",
+        on_delete=models.CASCADE
+    )
 
     def __str__(self):
         return self.value
@@ -676,7 +680,11 @@ class ReplaceAttributName(models.Model):
     #: ForeignKey to a :class:`ServicePattern`. :class:`ReplaceAttributName` instances for a
     #: :class:`ServicePattern` are accessible thought its :attr:`ServicePattern.attributs`
     #: attribute.
-    service_pattern = models.ForeignKey(ServicePattern, related_name="attributs")
+    service_pattern = models.ForeignKey(
+        ServicePattern,
+        related_name="attributs",
+        on_delete=models.CASCADE
+    )
 
     def __str__(self):
         if not self.replace:
@@ -711,7 +719,11 @@ class FilterAttributValue(models.Model):
     #: ForeignKey to a :class:`ServicePattern`. :class:`FilterAttributValue` instances for a
     #: :class:`ServicePattern` are accessible thought its :attr:`ServicePattern.filters`
     #: attribute.
-    service_pattern = models.ForeignKey(ServicePattern, related_name="filters")
+    service_pattern = models.ForeignKey(
+        ServicePattern,
+        related_name="filters",
+        on_delete=models.CASCADE
+    )
 
     def __str__(self):
         return u"%s %s" % (self.attribut, self.pattern)
@@ -748,7 +760,11 @@ class ReplaceAttributValue(models.Model):
     #: ForeignKey to a :class:`ServicePattern`. :class:`ReplaceAttributValue` instances for a
     #: :class:`ServicePattern` are accessible thought its :attr:`ServicePattern.replacements`
     #: attribute.
-    service_pattern = models.ForeignKey(ServicePattern, related_name="replacements")
+    service_pattern = models.ForeignKey(
+        ServicePattern,
+        related_name="replacements",
+        on_delete=models.CASCADE
+    )
 
     def __str__(self):
         return u"%s %s %s" % (self.attribut, self.pattern, self.replace)
@@ -764,14 +780,18 @@ class Ticket(JsonAttributes):
     class Meta:
         abstract = True
     #: ForeignKey to a :class:`User`.
-    user = models.ForeignKey(User, related_name="%(class)s")
+    user = models.ForeignKey(User, related_name="%(class)s", on_delete=models.CASCADE)
     #: A boolean. ``True`` if the ticket has been validated
     validate = models.BooleanField(default=False)
     #: The service url for the ticket
     service = models.TextField()
     #: ForeignKey to a :class:`ServicePattern`. The :class:`ServicePattern` corresponding to
     #: :attr:`service`. Use :meth:`ServicePattern.validate` to find it.
-    service_pattern = models.ForeignKey(ServicePattern, related_name="%(class)s")
+    service_pattern = models.ForeignKey(
+        ServicePattern,
+        related_name="%(class)s",
+        on_delete=models.CASCADE
+    )
     #: Date of the ticket creation
     creation = models.DateTimeField(auto_now_add=True)
     #: A boolean. ``True`` if the user has just renew his authentication
@@ -1034,7 +1054,7 @@ class Proxy(models.Model):
     #: ForeignKey to a :class:`ProxyTicket`. :class:`Proxy` instances for a
     #: :class:`ProxyTicket` are accessible thought its :attr:`ProxyTicket.proxies`
     #: attribute.
-    proxy_ticket = models.ForeignKey(ProxyTicket, related_name="proxies")
+    proxy_ticket = models.ForeignKey(ProxyTicket, related_name="proxies", on_delete=models.CASCADE)
 
     def __str__(self):
         return self.url
@@ -1077,7 +1097,7 @@ Upgrade using:
     * pip install -U django-cas-server
     * fetching the last release on
       https://github.com/nitmir/django-cas-server/ or on
-      https://pypi.python.org/pypi/django-cas-server
+      https://pypi.org/project/django-cas-server/
 
 After upgrade, do not forget to run:
     * ./manage.py migrate
